@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::MintingProfile::Author::ETHER;
 {
-  $Dist::Zilla::MintingProfile::Author::ETHER::VERSION = '0.012';
+  $Dist::Zilla::MintingProfile::Author::ETHER::VERSION = '0.013';
 }
 BEGIN {
   $Dist::Zilla::MintingProfile::Author::ETHER::AUTHORITY = 'cpan:ETHER';
@@ -30,7 +30,7 @@ Dist::Zilla::MintingProfile::Author::ETHER - Mint distributions like ETHER does
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -62,7 +62,9 @@ Profiles available are:
 C<github>
 
 Creates a distribution hosted on L<github|http://github.com>, with hooks to determine the
-module version and other metadata from git.
+module version and other metadata from git. Issue tracking is disabled, as RT
+is selected as the bugtracker in the distribution's metadata (via the plugin
+bundle).
 
 You will be prompted to create a repository on github immediately; if you
 decline, you must create one manually before you do your first C<push>.
